==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AVolatileModifier.h <==
// public final class soot.jimple.parser.node.AVolatileModifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9bdd9fdcc35b989 soot_jimple_parser_node_AVolatileModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AVolatileModifier_H_
#define _JC_soot_jimple_parser_node_AVolatileModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TVolatile$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_refs	_jc_soot_jimple_parser_node_AVolatileModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$refs	_jc_soot_jimple_parser_node_AVolatileModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$nonrefs	_jc_soot_jimple_parser_node_AVolatileModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$object	_jc_soot_jimple_parser_node_AVolatileModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AVolatileModifier$vmethods	_jc_soot_jimple_parser_node_AVolatileModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AVolatileModifier$vtable	_jc_soot_jimple_parser_node_AVolatileModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AVolatileModifier$vtype	_jc_soot_jimple_parser_node_AVolatileModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *);
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$_init$568bb1ba8955f839(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_TVolatile$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AVolatileModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *);
extern struct _jc_soot_jimple_parser_node_TVolatile$object *_jc_soot_jimple_parser_node_AVolatileModifier$method$getVolatile$c0268162ff94ec79(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *);
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$setVolatile$3f7359db2182bb71(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_TVolatile$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AVolatileModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$getVolatile$c0268162ff94ec79;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$setVolatile$3f7359db2182bb71;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AVolatileModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *);
	struct _jc_soot_jimple_parser_node_TVolatile$object	*(*getVolatile$c0268162ff94ec79)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setVolatile$3f7359db2182bb71)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_TVolatile$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AVolatileModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AVolatileModifier$vmethods	soot_jimple_parser_node_AVolatileModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AVolatileModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AVolatileModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TVolatile$object	*__5fvolatile__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVolatileModifier$refs {
    _jc_soot_jimple_parser_node_AVolatileModifier$sub_refs	soot_jimple_parser_node_AVolatileModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVolatileModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs	soot_jimple_parser_node_AVolatileModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AVolatileModifier$object {
	_jc_soot_jimple_parser_node_AVolatileModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AVolatileModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AVolatileModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AVolatileModifier$vtype _jc_soot_jimple_parser_node_AVolatileModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AVolatileModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AVolatileModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AVolatileModifier_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AVolatileModifier.h <==
// public final class soot.jimple.parser.node.AVolatileModifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9bdd9fdcc35b989 soot_jimple_parser_node_AVolatileModifier
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 3b296b90432e6f7 soot_jimple_parser_node_PModifier

// header file dependencies
// @dep_header soot_jimple_parser_node_PModifier

#include "soot/jimple/parser/node/PModifier.h"

#ifndef _JC_soot_jimple_parser_node_AVolatileModifier_H_
#define _JC_soot_jimple_parser_node_AVolatileModifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TVolatile$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_refs	_jc_soot_jimple_parser_node_AVolatileModifier$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs	_jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$refs	_jc_soot_jimple_parser_node_AVolatileModifier$refs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$nonrefs	_jc_soot_jimple_parser_node_AVolatileModifier$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVolatileModifier$object	_jc_soot_jimple_parser_node_AVolatileModifier$object;

typedef const struct _jc_soot_jimple_parser_node_AVolatileModifier$vmethods	_jc_soot_jimple_parser_node_AVolatileModifier$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AVolatileModifier$vtable	_jc_soot_jimple_parser_node_AVolatileModifier$vtable;
typedef const struct _jc_soot_jimple_parser_node_AVolatileModifier$vtype	_jc_soot_jimple_parser_node_AVolatileModifier$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$_init$568bb1ba8955f839(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_TVolatile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AVolatileModifier$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TVolatile$object *_jc_soot_jimple_parser_node_AVolatileModifier$method$getVolatile$c0268162ff94ec79(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVolatileModifier$method$setVolatile$3f7359db2182bb71(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_TVolatile$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AVolatileModifier$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$getVolatile$c0268162ff94ec79;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$setVolatile$3f7359db2182bb71;
extern _jc_method _jc_soot_jimple_parser_node_AVolatileModifier$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AVolatileModifier$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TVolatile$object	*(*getVolatile$c0268162ff94ec79)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setVolatile$3f7359db2182bb71)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *, struct _jc_soot_jimple_parser_node_TVolatile$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AVolatileModifier$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AVolatileModifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PModifier$vmethods	soot_jimple_parser_node_PModifier;
	_jc_soot_jimple_parser_node_AVolatileModifier$vmethods	soot_jimple_parser_node_AVolatileModifier;
};

// Vtype
struct _jc_soot_jimple_parser_node_AVolatileModifier$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AVolatileModifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_refs {
	struct _jc_soot_jimple_parser_node_TVolatile$object	*__5fvolatile__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVolatileModifier$refs {
    _jc_soot_jimple_parser_node_AVolatileModifier$sub_refs	soot_jimple_parser_node_AVolatileModifier;
    _jc_soot_jimple_parser_node_PModifier$sub_refs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVolatileModifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PModifier$sub_nonrefs	soot_jimple_parser_node_PModifier;
    _jc_soot_jimple_parser_node_AVolatileModifier$sub_nonrefs	soot_jimple_parser_node_AVolatileModifier;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AVolatileModifier$object {
	_jc_soot_jimple_parser_node_AVolatileModifier$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AVolatileModifier$vtype	*vtype;
	_jc_soot_jimple_parser_node_AVolatileModifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AVolatileModifier$vtype _jc_soot_jimple_parser_node_AVolatileModifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AVolatileModifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AVolatileModifier$class_object;

#endif	/* _JC_soot_jimple_parser_node_AVolatileModifier_H_ */
